@@ -105,7 +105,7 @@
 
 #define tmpdir "/tmp"
 #define program "empty"
-#define version "0.6.19b" 
+#define version "0.6.20b" 
 
 /* -------------------------------------------------------------------------- */
 static void usage(void);
@@ -179,25 +179,24 @@ int main (int argc, char *argv[]) {
 					   2 - unknown */
 	
 /* semaphores */
-#ifdef _POSIX_SEMAPHORES
-	#if defined(__linux__) && defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED)
-		/* union semun is defined by including <sys/sem.h> */
-	#else
-		union semun {
-			int val;
-			struct semid_ds *buf;
-		#ifdef __SVR4
-			ushort_t	*array;
-		#endif
-		#ifdef __hpux__
-			ushort		*array;
-		#endif
-		#ifdef __linux__
-			unsigned short *array;
-			struct seminfo *__buf;		/* buffer for IPC_INFO */
-		#endif
-		};
-  	#endif
+/* Thanks to Waldemar Brodkorb <wbx@openadk.org> for the fix of semaphores nature */
+#if defined(__linux__) && defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED)
+	/* union semun is defined by including <sys/sem.h> */
+#else
+	union semun {
+		int val;
+		struct semid_ds *buf;
+	#ifdef __SVR4
+		ushort_t	*array;
+	#endif
+	#ifdef __hpux__
+		ushort		*array;
+	#endif
+	#ifdef __linux__
+		unsigned short *array;
+		struct seminfo *__buf;		/* buffer for IPC_INFO */
+	#endif
+	};
 #endif
 	union semun semu;
 	
@@ -585,7 +584,7 @@ int main (int argc, char *argv[]) {
 
 		for (i = 1; i < argc; i++) {
 			strncat(buf, " ", 1);
-			strncat(buf, argv[i], sizeof(buf));
+			strncat(buf, argv[i], sizeof(buf) - strlen(buf) - 1);
 		}
 
 		(void)syslog(LOG_NOTICE, "forked %s", buf);
